@@ -14,6 +14,7 @@
 
 from selenium import webdriver
 
+from .connectiontype import ConnectionType
 from .mobilecommand import MobileCommand as Command
 from .errorhandler import MobileErrorHandler
 from .switch_to import MobileSwitchTo
@@ -569,6 +570,80 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.OPEN_NOTIFICATIONS, {})
         return self
 
+    @property
+    def network_connection(self):
+        """Returns an integer bitmask specifying the network connection type.
+        Android only.
+        Possible values are available through the enumeration `appium.webdriver.ConnectionType`
+        """
+        return self.execute(Command.GET_NETWORK_CONNECTION, {})['value']
+
+    def set_network_connection(self, connectionType):
+        """Sets the network connection type. Android only.
+        Possible values:
+            Value (Alias)      | Data | Wifi | Airplane Mode
+            -------------------------------------------------
+            0 (None)           | 0    | 0    | 0
+            1 (Airplane Mode)  | 0    | 0    | 1
+            2 (Wifi only)      | 0    | 1    | 0
+            4 (Data only)      | 1    | 0    | 0
+            6 (All network on) | 1    | 1    | 0
+        These are available through the enumeration `appium.webdriver.ConnectionType`
+
+        :Args:
+         - connectionType - a member of the enum appium.webdriver.ConnectionType
+        """
+        data = {
+            'parameters': {
+                'type': connectionType.value
+            }
+        }
+        return self.execute(Command.SET_NETWORK_CONNECTION, data)['value']
+
+    @property
+    def available_ime_engines(self):
+        """Get the available input methods for an Android device. Package and
+        activity are returned (e.g., ['com.android.inputmethod.latin/.LatinIME'])
+        Android only.
+        """
+        return self.execute(Command.GET_AVAILABLE_IME_ENGINES, {})['value']
+
+    def is_ime_active(self):
+        """Checks whether the device has IME service active. Returns True/False.
+        Android only.
+        """
+        return self.execute(Command.IS_IME_ACTIVE, {})['value']
+
+    def activate_ime_engine(self, engine):
+        """Activates the given IME engine on the device.
+        Android only.
+
+        :Args:
+         - engine - the package and activity of the IME engine to activate (e.g.,
+            'com.android.inputmethod.latin/.LatinIME')
+        """
+        data = {
+            'engine': engine
+        }
+        self.execute(Command.ACTIVATE_IME_ENGINE, data)
+        return self
+
+    def deactivate_ime_engine(self):
+        """Deactivates the currently active IME engine on the device.
+        Android only.
+        """
+        self.execute(Command.DEACTIVATE_IME_ENGINE, {})
+        return self
+
+    @property
+    def active_ime_engine(self):
+        """Returns the activity and package of the currently active IME engine (e.g.,
+        'com.android.inputmethod.latin/.LatinIME').
+        Android only.
+        """
+        return self.execute(Command.GET_ACTIVE_IME_ENGINE, {})['value']
+
+
     def _addCommands(self):
         self.command_executor._commands[Command.CONTEXTS] = \
             ('GET', '/session/$sessionId/contexts')
@@ -625,6 +700,20 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/hide_keyboard')
         self.command_executor._commands[Command.OPEN_NOTIFICATIONS] = \
             ('POST', '/session/$sessionId/appium/device/open_notifications')
+        self.command_executor._commands[Command.GET_NETWORK_CONNECTION] = \
+            ('GET', '/session/$sessionId/network_connection')
+        self.command_executor._commands[Command.SET_NETWORK_CONNECTION] = \
+            ('POST', '/session/$sessionId/network_connection')
+        self.command_executor._commands[Command.GET_AVAILABLE_IME_ENGINES] = \
+            ('GET', '/session/$sessionId/ime/available_engines')
+        self.command_executor._commands[Command.IS_IME_ACTIVE] = \
+            ('GET', '/session/$sessionId/ime/activated')
+        self.command_executor._commands[Command.ACTIVATE_IME_ENGINE] = \
+            ('POST', '/session/$sessionId/ime/activate')
+        self.command_executor._commands[Command.DEACTIVATE_IME_ENGINE] = \
+            ('POST', '/session/$sessionId/ime/deactivate')
+        self.command_executor._commands[Command.GET_ACTIVE_IME_ENGINE] = \
+            ('GET', '/session/$sessionId/ime/active_engine')
 
 
 # monkeypatched method for WebElement
